Welcome to taurenmd Documentation!
===================================

.. include:: ../README.rst
   :start-after: .. start-description
   :end-before: .. end-description

You can read now through the **contents** bellow.


Contents
========

.. toctree::
   :maxdepth: 1

   installation
   usage
   reference/clients
   contributing
   citing
   authors
   acknowledgments
   license
   versioning
   reference/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


